@@ -1613,10 +1613,10 @@ void Titraqform::helpContents(void)
 void Titraqform::aboutTitraq(void)
 {
     QMessageBox *pCwmsg = new QMessageBox("AS Accounting System",
-        QObject::trUtf8("As-gui is a time and task-based\n"
+        QObject::trUtf8("AS-GUI is a time and task-based\n"
                "accounting system that acts as both a\n"
                "work-like punch card and time tracker.\n"
-               "Development of titraq is sponsored by\n"
+               "Development of AS-GUI is sponsored by\n"
                "Cable & Wireless Deutschland GmbH."),
         QMessageBox::NoIcon, QMessageBox::Ok | QMessageBox::Default,
         QMessageBox::NoButton, QMessageBox::NoButton,
