@@ -134,6 +134,6 @@ private:
     void setId(const unsigned char *);  // Helper method to set data members
     int setMac(unsigned char *);        // Helper method to set MAC node ID
 };
-}
+} // namespace AS
 
 #endif // UUIDGEN_H
